#! /bin/bash
### BEGIN INIT INFO
# Provides:          bipom_installer
# Required-Start:    mountkernfs 
# Required-Stop:
# Should-Start:      
# Default-Start:     S
# Default-Stop:
# X-Interactive:     true
# Short-Description: Check all filesystems.
### END INIT INFO
################################################################################################
#                                        
# bipom_installer.sh - BiPOM Installer  shell file  
#                                        
################################################################################################
echo "Start BiPOM Installer ..."
echo "VER: 1.01 02/15/2010"
################################################################################################
# Define driver names we need to install to both platforms
COMMON_NAME=(mii.ko ax88796.ko asix.ko usbnet.ko dm9601.ko input-polldev.ko rt2x00lib.ko
rt2x00usb.ko rt73usb.ko usbserial.ko ftdi_sio.ko sierra.ko cdc-acm.ko cdc_subset.ko 
hid.ko gspca_main.ko gspca_pac7311.ko gspca_zc3xx.ko uvcvideo.ko ldusb.ko at91adc.ko END)
# Define driver names we need to install to GadgetPC
GADGETPC_NAME=(END)
# Define driver names we need to install to MMARM9
MMARM9_NAME=(pca9698.ko macb.ko davicom.ko fb_sys_fops.ko syscopyarea.ko sysfillrect.ko
sysimgblt.ko sysimgblt.ko fb.ko ili9325.ko sc16is7x2.ko END)
################################################################################################
BOARD=`/usr/bin/boardinfo -b`
LINUX_VERSION=`uname -r`
DRIVER_INSTALL='/lib/modules/'${LINUX_VERSION}
DRIVER_SOURCE='/lib/modules/drivers'
DRIVER_I_FILE=UNKNOWN
DRIVER_S_FILE=UNKNOWN
DRIVER_NAME=UNKNOWN
IS_SUCCESS=YES
IS_DEPMODE=NO
################################################################################################
function checkDriver {
	DRIVER_I_FILE=${DRIVER_INSTALL}'/'${DRIVER_NAME}
	DRIVER_S_FILE=${DRIVER_SOURCE}'/'${DRIVER_NAME}
	if [ -f ${DRIVER_I_FILE} ]; then
		echo "${DRIVER_I_FILE} OK"
	else
		echo "${DRIVER_I_FILE} not found.Installing..."
		if [ -f ${DRIVER_S_FILE} ]; then
			echo "${DRIVER_S_FILE} found.Installing"
			install -c -m 0644 ${DRIVER_S_FILE} ${DRIVER_I_FILE}
			IS_DEPMODE=YES
			echo "${DRIVER_I_FILE} OK"
		else
			echo "ERROR: ${DRIVER_S_FILE} not found"
			IS_SUCCESS=NO
		fi
	fi
}
################################################################################################
function removeDriver {
	DRIVER_I_FILE=${DRIVER_INSTALL}'/'${DRIVER_NAME}
	if [ -f ${DRIVER_I_FILE} ]; then
		rm -f ${DRIVER_I_FILE}
		if [ -f ${DRIVER_I_FILE} ]; then
			echo "ERROR: can't remove ${DRIVER_I_FILE}"
		else
			echo "${DRIVER_I_FILE} removed"
		fi
		IS_DEPMODE=YES
	fi
}
################################################################################################
if [ ${BOARD} = "GadgetPC" ]; then	
	echo "Detected board: GadgetPC"
# Remove MMARM9 drivers	
	INDEX=0
	while [ ${MMARM9_NAME[$INDEX]} != "END" ]; do
		DRIVER_NAME=${MMARM9_NAME[$INDEX]}
		removeDriver
		INDEX=$(expr $INDEX + 1 )
	done
#  Install GadgetPC drivers	
	INDEX=0
	while [ ${GADGETPC_NAME[$INDEX]} != "END" ]; do
		DRIVER_NAME=${GADGETPC_NAME[$INDEX]}
		checkDriver
		INDEX=$(expr $INDEX + 1 )
	done
fi
################################################################################################
if [ ${BOARD} = "MMARM9" ]; then	
	echo "Detected board: Mini-Max/ARM9"
#  emove GadgetPC drivers	
	INDEX=0
	while [ ${GADGETPC_NAME[$INDEX]} != "END" ]; do
		DRIVER_NAME=${GADGETPC_NAME[$INDEX]}
		removeDriver
		INDEX=$(expr $INDEX + 1 )
	done
# Install MMARM9 drivers	
	INDEX=0
	while [ ${MMARM9_NAME[$INDEX]} != "END" ]; do
		DRIVER_NAME=${MMARM9_NAME[$INDEX]}
		checkDriver
		INDEX=$(expr $INDEX + 1 )
	done
fi
################################################################################################
# Check all COMMON drivers and install  the missing ones if it is necessary 
INDEX=0
while [ ${COMMON_NAME[$INDEX]} != "END" ]; do
	DRIVER_NAME=${COMMON_NAME[$INDEX]}
	checkDriver
	INDEX=$(expr $INDEX + 1 )
done
################################################################################################
if [ ${BOARD} = "GadgetPC" ]; then
	echo "Initialize unused port pins of GadgetPC"
	for port_pin in $(seq 3 31) ; do
		gpio A $port_pin 0 > /dev/null
	done
	for port_pin in $(seq 0 3) ; do
		gpio B $port_pin 0  > /dev/null
	done
	for port_pin in $(seq 6 31) ; do
		gpio B $port_pin 0  > /dev/null
	done
	for port_pin in 0 1 2 3 6 8 9 10 ; do
		gpio C $port_pin 0  > /dev/null
	done
	for port_pin in $(seq 13 31) ; do
		gpio C $port_pin 0  > /dev/null
	done
fi
################################################################################################
if [ ${IS_DEPMODE} = "YES" ]; then	
	echo "Execute 'depmod -a'"
	depmod -a
fi
################################################################################################
if [ ${IS_SUCCESS} = "YES" ]; then	
	echo "INSTALLATION/CHECK PASSED"
else
	echo "INSTALLATION FAILED"
fi
#EOF



